@@ -33,7 +33,8 @@ OPTIONS = {
     'e': "expire_duration;Duration (in seconds) for which, dns entries are"
          " stored in redis. Pass 0 for infinity. Default: 86400 (1 Day)",
     'H': "redis_host;Address of redis server. Default: localhost",
-    'p': "redis_port_no;Port No. of redis server. Default: 6379",
+    'P': "redis_port_no;Port No. of redis server. Default: 6379",
+    'p': "redis_password;Redis password (optional)",
 }
 FLAG_OPTIONS = {
     'E': "no_ec2;Dont sync ec2 instance details in redis. Private ip and "
@@ -56,6 +57,7 @@ DEFAULTS = {
     "no_ec2": False,
     "no_route53": False,
     "ttl": False,
+    "redis_password": '',
 }
 
 ## Global variable for indexing
@@ -75,6 +77,8 @@ def validate_arguments(option_args):
     redis_host = option_args.redis_host or DEFAULTS.get('redis_host', None)
     redis_port_no = option_args.redis_port_no or DEFAULTS.get('redis_port_no',
                                                               None)
+    redis_password = option_args.redis_password or DEFAULTS.get(
+        'redis_password', None)
     no_ec2 = option_args.no_ec2 or DEFAULTS.get('no_ec2', None)
     no_route53 = option_args.no_route53 or DEFAULTS.get('no_route53', None)
     ttl = option_args.ttl or DEFAULTS.get('ttl', None)
@@ -86,6 +90,7 @@ def validate_arguments(option_args):
         "expire_duration": expire_duration,
         "redis_host": redis_host,
         "redis_port_no": redis_port_no,
+        "redis_password": redis_password,
         "no_ec2": no_ec2,
         "no_route53": no_route53,
         "ttl": ttl,
@@ -173,15 +178,18 @@ def sync_ec2(redis_handler, apikey, apisecret, regions, expire):
     thread_list = []
     for region in region_list:
         ec2_handler = aws.ec2.Ec2Handler(apikey, apisecret, region)
-        thread = gevent.spawn(sync_ec2_instances, ec2_handler, expire)
+        thread = gevent.spawn(sync_ec2_instances, redis_handler, ec2_handler,
+                              expire)
         thread_list.append(thread)
-        thread = gevent.spawn(sync_ec2_elbs, ec2_handler, expire)
+        thread = gevent.spawn(sync_ec2_elbs, redis_handler, ec2_handler,
+                              expire)
         thread_list.append(thread)
-        thread = gevent.spawn(sync_elastic_ips, ec2_handler, expire)
+        thread = gevent.spawn(sync_elastic_ips, redis_handler, ec2_handler,
+                              expire)
         thread_list.append(thread)
     return thread_list
 
-def sync_ec2_instances(ec2_handler, expire):
+def sync_ec2_instances(redis_handler, ec2_handler, expire):
     global index_keys
     try:
         instance_list = ec2_handler.fetch_all_instances()
@@ -198,7 +206,7 @@ def sync_ec2_instances(ec2_handler, expire):
             redis_handler.expire(hash_key, expire)
     print "Instance sync complete for ec2 region: %s" % ec2_handler.region
 
-def sync_ec2_elbs(ec2_handler, expire):
+def sync_ec2_elbs(redis_handler, ec2_handler, expire):
     global index_keys
     try:
         elb_list = ec2_handler.fetch_all_elbs()
@@ -229,7 +237,7 @@ def sync_ec2_elbs(ec2_handler, expire):
             redis_handler.expire(hash_key, expire)
     print "ELB sync complete for ec2 region: %s" % ec2_handler.region
 
-def sync_elastic_ips(ec2_handler, expire):
+def sync_elastic_ips(redis_handler, ec2_handler, expire):
     global index_keys
     try:
         elastic_ip_list = ec2_handler.fetch_elastic_ips()
@@ -295,8 +303,8 @@ if __name__ == '__main__':
     route53_handler = aws.route53.Route53Handler(apikey=arguments['apikey'],
         apisecret=arguments['apisecret'])
     redis_handler = database.redis_handler.RedisHandler(
-        host=arguments['redis_host'], port=arguments['redis_port_no'])
-
+        host=arguments['redis_host'], port=arguments['redis_port_no'],
+        password=arguments['redis_password'])
     thread_list = []
     if not arguments['no_route53']:
         new_threads = sync_route53(route53_handler, redis_handler,
